@@ -1,6 +1,6 @@
-from CLUIE import engine
+from CLUIE import *
 from view_generator import *
 from models import *
 
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 __author__ = 'Mateusz Golembowski'
\ No newline at end of file
